@@ -6,7 +6,8 @@ data("sc_example")
 iris_clusts2 <- iris_clusts
 iris_clusts2[["A-1"]] <- iris_clusts2$Sepal.Length
 
-if (requireNamespace("Seurat", quietly = TRUE)) {
+if (requireNamespace("Seurat", quietly = TRUE) &&
+    packageVersion(pkg = "Seurat") < package_version(x = "3.0.0")) {
     library("Seurat")
     seurat <- CreateSeuratObject(sc_example$counts,
                                  meta.data = sc_example$seurat_clusters)
@@ -14,12 +15,25 @@ if (requireNamespace("Seurat", quietly = TRUE)) {
                               sc_example$tsne)
 }
 
+if (requireNamespace("Seurat", quietly = TRUE) &&
+    packageVersion(pkg = "Seurat") >= package_version(x = "3.0.0")) {
+    library("Seurat")
+    seurat <- CreateSeuratObject(counts = sc_example$counts,
+                                 meta.data = sc_example$seurat_clusters)
+    seurat[["TSNE"]] <- suppressWarnings(CreateDimReducObject(
+        embeddings = sc_example$tsne,
+        key = "tSNE_",
+        assay = DefaultAssay(seurat)
+    ))
+}
+
 if (requireNamespace("SingleCellExperiment", quietly = TRUE)) {
     library("SingleCellExperiment")
-    sce <- SingleCellExperiment(assays = list(counts = sc_example$counts,
-                                              logcounts = sc_example$logcounts),
-                                colData = sc_example$sc3_clusters,
-                                reducedDims = SimpleList(TSNE = sc_example$tsne))
+    sce <- SingleCellExperiment(
+        assays = list(counts = sc_example$counts,
+                      logcounts = sc_example$logcounts),
+        colData = sc_example$sc3_clusters,
+        reducedDims = SimpleList(TSNE = sc_example$tsne))
 }
 
 test_that("data.frame interface works", {
@@ -34,7 +48,7 @@ test_that("SingleCellExperiment interface works", {
 
 test_that("Seurat interface works", {
     skip_if_not_installed("Seurat")
-    expect_is(clustree(seurat), c("gg", "ggplot"))
+    expect_is(clustree(seurat, prefix = "res."), c("gg", "ggplot"))
 })
 
 test_that("column number check works", {
@@ -74,7 +88,7 @@ test_that("returning layout works", {
 test_that("show_axis works", {
     expect_is(clustree(iris_clusts, prefix = "K", show_axis = TRUE),
               c("gg", "ggplot"))
-    expect_is(clustree(seurat, show_axis = TRUE),
+    expect_is(clustree(seurat, prefix = "res.", show_axis = TRUE),
               c("gg", "ggplot"))
     expect_is(clustree(sce, prefix = "sc3_", suffix = "_clusters",
                        show_axis = TRUE),
